@@ -274,11 +274,11 @@ $$ language plpgsql;
                     from batch_log
                     where true
                     and status = %(from_status)s
-                    and gcra_throttle(throttle_key, throttle_limit, throttle_period, true) as wait_millis <=0
-                    order by priority desc, updated_at asc, wait_millis desc
+                    and gcra_throttle(throttle_key, throttle_limit, throttle_period, true)::int <=0
+                    order by priority desc, updated_at asc
                     limit 1
                 )
-                returning id, priority, data, result, type, status, wait_millis, source, created_at, updated_at
+                returning id, priority, data, result, type, status, source, created_at, updated_at
                 ;
                 """,
             {"from_status": (from_status,), "to_status": (to_status,)},
